@@ -47,7 +47,7 @@ def assert_size_argument_jax_compatible(node):
     size = node.inputs[1]
     size_node = size.owner
     if (size_node is not None) and (
-        not isinstance(size_node.op, (Shape, Shape_i, JAXShapeTuple))
+        not isinstance(size_node.op, Shape | Shape_i | JAXShapeTuple)
     ):
         raise NotImplementedError(SIZE_NOT_COMPATIBLE)
 
