@@ -5,7 +5,6 @@ from contextlib import contextmanager
 from copy import copy
 from functools import singledispatch
 from textwrap import dedent
-from typing import Union
 
 import numba
 import numba.np.unsafe.ndarray as numba_ndarray
@@ -14,7 +13,7 @@ import scipy
 import scipy.special
 from llvmlite import ir
 from numba import types
-from numba.core.errors import TypingError
+from numba.core.errors import NumbaWarning, TypingError
 from numba.cpython.unsafe.tuple import tuple_setitem  # noqa: F401
 from numba.extending import box, overload
 
@@ -61,6 +60,13 @@ def global_numba_func(func):
 def numba_njit(*args, **kwargs):
     kwargs.setdefault("cache", config.numba__cache)
 
+    # Supress caching warnings
+    warnings.filterwarnings(
+        "ignore",
+        message='Cannot cache compiled function "numba_funcified_fgraph" as it uses dynamic globals',
+        category=NumbaWarning,
+    )
+
     if len(args) > 0 and callable(args[0]):
         return numba.njit(*args[1:], **kwargs)(args[0])
 
@@ -120,7 +126,7 @@ def get_numba_type(
 
 
 def create_numba_signature(
-    node_or_fgraph: Union[FunctionGraph, Apply],
+    node_or_fgraph: FunctionGraph | Apply,
     force_scalar: bool = False,
     reduce_to_scalar: bool = False,
 ) -> numba.types.Type:
@@ -218,7 +224,7 @@ def to_scalar(x):
 
 @numba.extending.overload(to_scalar)
 def impl_to_scalar(x):
-    if isinstance(x, (numba.types.Number, numba.types.Boolean)):
+    if isinstance(x, numba.types.Number | numba.types.Boolean):
         return lambda x: x
     elif isinstance(x, numba.types.Array):
         return lambda x: x.item()
@@ -477,7 +483,7 @@ def create_index_func(node, objmode=False):
             raise ValueError()
 
     set_or_inc = isinstance(
-        node.op, (IncSubtensor, AdvancedIncSubtensor1, AdvancedIncSubtensor)
+        node.op, IncSubtensor | AdvancedIncSubtensor1 | AdvancedIncSubtensor
     )
     index_start_idx = 1 + int(set_or_inc)
 
