@@ -1,5 +1,4 @@
 from collections.abc import Collection, Iterable
-from typing import Optional, Union
 
 import numpy as np
 from numpy.core.multiarray import normalize_axis_index
@@ -280,7 +279,7 @@ class CumOp(COp):
         c_axis=int_t, mode=EnumList(("MODE_ADD", "add"), ("MODE_MUL", "mul"))
     )
 
-    def __init__(self, axis: Optional[int] = None, mode="add"):
+    def __init__(self, axis: int | None = None, mode="add"):
         if mode not in ("add", "mul"):
             raise ValueError(f'{type(self).__name__}: Unknown mode "{mode}"')
         self.axis = axis
@@ -1348,7 +1347,7 @@ def unravel_index(indices, dims, order="C"):
 
     """
     res = UnravelIndex(order=order)(indices, dims)
-    if not isinstance(res, (list, tuple)):
+    if not isinstance(res, list | tuple):
         return (res,)
     else:
         return tuple(res)
@@ -1425,7 +1424,7 @@ def ravel_multi_index(multi_index, dims, mode="raise", order="C"):
     unravel_index
 
     """
-    if not isinstance(multi_index, (tuple, list)):
+    if not isinstance(multi_index, tuple | list):
         raise TypeError("multi_index must be a tuple or a list.")
     args = (*multi_index, dims)
     return RavelMultiIndex(mode=mode, order=order)(*args)
@@ -1458,7 +1457,7 @@ def broadcast_shape(*arrays, **kwargs) -> tuple[ps.ScalarVariable, ...]:
 
 
 def broadcast_shape_iter(
-    arrays: Iterable[Union[TensorVariable, tuple[TensorVariable, ...]]],
+    arrays: Iterable[TensorVariable | tuple[TensorVariable, ...]],
     arrays_are_shapes: bool = False,
     allow_runtime_broadcast: bool = False,
 ) -> tuple[ps.ScalarVariable, ...]:
@@ -1598,7 +1597,7 @@ def linspace(start, end, steps):
 
 
 def broadcast_to(
-    x: TensorVariable, shape: Union[TensorVariable, tuple[Variable, ...]]
+    x: TensorVariable, shape: TensorVariable | tuple[Variable, ...]
 ) -> TensorVariable:
     """Broadcast an array to a new shape.
 
