@@ -2,7 +2,7 @@ from collections.abc import Sequence
 from functools import wraps
 from itertools import zip_longest
 from types import ModuleType
-from typing import TYPE_CHECKING, Literal, Optional, Union
+from typing import TYPE_CHECKING, Literal
 
 import numpy as np
 
@@ -13,7 +13,7 @@ from pytensor.tensor import get_vector_length
 from pytensor.tensor.basic import as_tensor_variable, cast, constant
 from pytensor.tensor.extra_ops import broadcast_to
 from pytensor.tensor.math import maximum
-from pytensor.tensor.shape import specify_shape
+from pytensor.tensor.shape import shape_padleft, specify_shape
 from pytensor.tensor.type import int_dtypes
 from pytensor.tensor.variable import TensorVariable
 
@@ -121,15 +121,43 @@ def broadcast_params(params, ndims_params):
     return bcast_params
 
 
+def explicit_expand_dims(
+    params: Sequence[TensorVariable],
+    ndim_params: tuple[int],
+    size_length: int = 0,
+) -> list[TensorVariable]:
+    """Introduce explicit expand_dims in RV parameters that are implicitly broadcasted together and/or by size."""
+
+    batch_dims = [
+        param.type.ndim - ndim_param for param, ndim_param in zip(params, ndim_params)
+    ]
+
+    if size_length:
+        # NOTE: PyTensor is currently treating zero-length size as size=None, which is not what Numpy does
+        # See: https://github.com/pymc-devs/pytensor/issues/568
+        max_batch_dims = size_length
+    else:
+        max_batch_dims = max(batch_dims)
+
+    new_params = []
+    for new_param, batch_dim in zip(params, batch_dims):
+        missing_dims = max_batch_dims - batch_dim
+        if missing_dims:
+            new_param = shape_padleft(new_param, missing_dims)
+        new_params.append(new_param)
+
+    return new_params
+
+
 def normalize_size_param(
-    size: Optional[Union[int, np.ndarray, Variable, Sequence]],
+    size: int | np.ndarray | Variable | Sequence | None,
 ) -> Variable:
     """Create an PyTensor value for a ``RandomVariable`` ``size`` parameter."""
     if size is None:
         size = constant([], dtype="int64")
     elif isinstance(size, int):
         size = as_tensor_variable([size], ndim=1)
-    elif not isinstance(size, (np.ndarray, Variable, Sequence)):
+    elif not isinstance(size, np.ndarray | Variable | Sequence):
         raise TypeError(
             "Parameter size must be None, an integer, or a sequence with integers."
         )
@@ -172,8 +200,8 @@ class RandomStream:
 
     def __init__(
         self,
-        seed: Optional[int] = None,
-        namespace: Optional[ModuleType] = None,
+        seed: int | None = None,
+        namespace: ModuleType | None = None,
         rng_ctor: Literal[
             np.random.RandomState, np.random.Generator
         ] = np.random.default_rng,
@@ -292,9 +320,9 @@ def supp_shape_from_ref_param_shape(
     *,
     ndim_supp: int,
     dist_params: Sequence[Variable],
-    param_shapes: Optional[Sequence[tuple[ScalarVariable, ...]]] = None,
+    param_shapes: Sequence[tuple[ScalarVariable, ...]] | None = None,
     ref_param_idx: int,
-) -> Union[TensorVariable, tuple[ScalarVariable, ...]]:
+) -> TensorVariable | tuple[ScalarVariable, ...]:
     """Extract the support shape of a multivariate `RandomVariable` from the shape of a reference parameter.
 
     Several multivariate `RandomVariable`s have a support shape determined by the last dimensions of a parameter.
