@@ -1,4 +1,4 @@
-""" Tensor optimizations addressing the ops in basic.py.
+"""Tensor optimizations addressing the ops in basic.py.
 
 Notes
 -----
@@ -23,7 +23,6 @@ Many stabilize and stabilization rewrites refuse to be applied when a variable h
 """
 
 import logging
-from typing import Union
 
 import numpy as np
 
@@ -136,11 +135,11 @@ def alloc_like(
 
 
 def register_useless(
-    node_rewriter: Union[RewriteDatabase, NodeRewriter, str], *tags, **kwargs
+    node_rewriter: RewriteDatabase | NodeRewriter | str, *tags, **kwargs
 ):
     if isinstance(node_rewriter, str):
 
-        def register(inner_rewriter: Union[RewriteDatabase, Rewriter]):
+        def register(inner_rewriter: RewriteDatabase | Rewriter):
             return register_useless(inner_rewriter, node_rewriter, *tags, **kwargs)
 
         return register
@@ -154,11 +153,11 @@ def register_useless(
 
 
 def register_canonicalize(
-    node_rewriter: Union[RewriteDatabase, NodeRewriter, str], *tags: str, **kwargs
+    node_rewriter: RewriteDatabase | NodeRewriter | str, *tags: str, **kwargs
 ):
     if isinstance(node_rewriter, str):
 
-        def register(inner_rewriter: Union[RewriteDatabase, Rewriter]):
+        def register(inner_rewriter: RewriteDatabase | Rewriter):
             return register_canonicalize(inner_rewriter, node_rewriter, *tags, **kwargs)
 
         return register
@@ -171,11 +170,11 @@ def register_canonicalize(
 
 
 def register_stabilize(
-    node_rewriter: Union[RewriteDatabase, NodeRewriter, str], *tags: str, **kwargs
+    node_rewriter: RewriteDatabase | NodeRewriter | str, *tags: str, **kwargs
 ):
     if isinstance(node_rewriter, str):
 
-        def register(inner_rewriter: Union[RewriteDatabase, Rewriter]):
+        def register(inner_rewriter: RewriteDatabase | Rewriter):
             return register_stabilize(inner_rewriter, node_rewriter, *tags, **kwargs)
 
         return register
@@ -188,11 +187,11 @@ def register_stabilize(
 
 
 def register_specialize(
-    node_rewriter: Union[RewriteDatabase, NodeRewriter, str], *tags: str, **kwargs
+    node_rewriter: RewriteDatabase | NodeRewriter | str, *tags: str, **kwargs
 ):
     if isinstance(node_rewriter, str):
 
-        def register(inner_rewriter: Union[RewriteDatabase, Rewriter]):
+        def register(inner_rewriter: RewriteDatabase | Rewriter):
             return register_specialize(inner_rewriter, node_rewriter, *tags, **kwargs)
 
         return register
@@ -205,11 +204,11 @@ def register_specialize(
 
 
 def register_uncanonicalize(
-    node_rewriter: Union[RewriteDatabase, NodeRewriter, str], *tags: str, **kwargs
+    node_rewriter: RewriteDatabase | NodeRewriter | str, *tags: str, **kwargs
 ):
     if isinstance(node_rewriter, str):
 
-        def register(inner_rewriter: Union[RewriteDatabase, Rewriter]):
+        def register(inner_rewriter: RewriteDatabase | Rewriter):
             return register_uncanonicalize(
                 inner_rewriter, node_rewriter, *tags, **kwargs
             )
@@ -958,6 +957,25 @@ def local_sum_make_vector(fgraph, node):
     return [element_sum]
 
 
+def equivalent_up_to_constant_casting(a, b) -> bool:
+    """Return True if a and b are equivalent up to constant casting."""
+    if a == b:
+        return True
+    # Return equivalence based on data values, ignoring dtype
+    if (
+        isinstance(a, TensorConstant)
+        and isinstance(b, TensorConstant)
+        and a.type.shape == b.type.shape
+        # We don't want to spend a lot of time comparing large constant arrays
+        # First, check if dtype matches, otherwise a == b would be true if they hold the same values
+        and a.type.dtype != b.type.dtype
+        # Check property sum() that is cached for TensorConstants, to filter down candidates even more
+        and a.signature().sum == b.signature().sum
+    ):
+        return np.array_equal(a.data, b.data)
+    return False
+
+
 @register_useless("shape_unsafe")
 @register_canonicalize("fast_compile", "shape_unsafe")
 @register_specialize("shape_unsafe")
@@ -984,7 +1002,7 @@ def local_useless_switch(fgraph, node):
     out_bcast = node.outputs[0].type.broadcastable
 
     if (isinstance(cond, np.ndarray) and cond.ndim == 0) or isinstance(
-        cond, (np.number, np.bool_)
+        cond, np.number | np.bool_
     ):
         if cond == 0:
             correct_out = right
@@ -1004,17 +1022,16 @@ def local_useless_switch(fgraph, node):
         return [out]
 
     # if left is right -> left
-    if left == right:
-        # Note: No need to copy over stacktrace, because the input node
-        # already has its own stacktrace
-        if left.type.broadcastable == out_bcast:
-            return [left]
+    if equivalent_up_to_constant_casting(left, right):
+        if left.type.broadcastable != out_bcast:
+            left, _ = broadcast_arrays(left, cond)
 
-        ret = broadcast_arrays(left, cond)[0]
+        out_dtype = node.outputs[0].type.dtype
+        if left.type.dtype != out_dtype:
+            left = cast(left, out_dtype)
 
-        # Copy over stacktrace from switch output and correct branch
-        copy_stack_trace(node.outputs + left, ret)
-        return [ret]
+        copy_stack_trace(node.outputs + node.inputs, left)
+        return [left]
 
     # This case happens with scan.
     # Elemwise{switch}(le(shape_i{id}(X), 0), 0, shape_i{id}(X)) -> shape_i{id}(X)
@@ -1044,7 +1061,7 @@ def local_merge_switch_same_cond(fgraph, node):
     """
     # node must be binary elemwise or add or mul
     if not isinstance(node.op, Elemwise) or not isinstance(
-        node.op.scalar_op, (ps.BinaryScalarOp, ps.Add, ps.Mul)
+        node.op.scalar_op, ps.BinaryScalarOp | ps.Add | ps.Mul
     ):
         return
     # all inputs must be switch
