@@ -1,7 +1,7 @@
 import warnings
 from numbers import Number
 from textwrap import dedent
-from typing import Union, cast
+from typing import cast
 
 import numpy as np
 
@@ -24,7 +24,7 @@ from pytensor.tensor.type_other import NoneConst
 from pytensor.tensor.variable import TensorConstant, TensorVariable
 
 
-ShapeValueType = Union[None, np.integer, int, Variable]
+ShapeValueType = None | np.integer | int | Variable
 
 
 def register_shape_c_code(type, code, version=()):
@@ -143,7 +143,7 @@ class Shape(COp):
 _shape = Shape()
 
 
-def shape(x: Union[np.ndarray, Number, Variable]) -> Variable:
+def shape(x: np.ndarray | Number | Variable) -> Variable:
     """Return the shape of `x`."""
     if not isinstance(x, Variable):
         # The following is a type error in Python 3.9 but not 3.12.
@@ -557,8 +557,8 @@ _specify_shape = SpecifyShape()
 
 
 def specify_shape(
-    x: Union[np.ndarray, Number, Variable],
-    shape: Union[ShapeValueType, list[ShapeValueType], tuple[ShapeValueType, ...]],
+    x: np.ndarray | Number | Variable,
+    shape: ShapeValueType | list[ShapeValueType] | tuple[ShapeValueType, ...],
 ):
     """Specify a fixed shape for a `Variable`.
 
@@ -566,7 +566,7 @@ def specify_shape(
     considered fixed/static at runtime.
     """
 
-    if not isinstance(shape, (tuple, list)):
+    if not isinstance(shape, tuple | list):
         shape = (shape,)
 
     # If shape is a symbolic 1d vector of fixed length, we separate the items into a
@@ -1032,7 +1032,7 @@ class Unbroadcast(COp):
         items = tuple(sorted(axis))
         self.axes = items
         for axis in self.axes:
-            if not isinstance(axis, (np.integer, int)):
+            if not isinstance(axis, np.integer | int):
                 raise TypeError(f"Unbroadcast needs integer axes. Got {axis}")
 
     def __str__(self):
