@@ -1,9 +1,8 @@
 import logging
 import sys
-from collections.abc import Iterable
+from collections.abc import Callable, Iterable
 from itertools import chain, groupby
 from textwrap import dedent
-from typing import Callable, Optional, Union
 
 import numpy as np
 
@@ -83,8 +82,8 @@ invalid_tensor_types = (
 
 def indices_from_subtensor(
     op_indices: Iterable[ScalarConstant],
-    idx_list: Optional[list[Union[Type, slice, Variable]]],
-) -> tuple[Union[slice, Variable], ...]:
+    idx_list: list[Type | slice | Variable] | None,
+) -> tuple[slice | Variable, ...]:
     """Recreate the index tuple from which a ``*Subtensor**`` ``Op`` was created.
 
     Parameters
@@ -129,8 +128,8 @@ def indices_from_subtensor(
 
 
 def as_index_constant(
-    a: Optional[Union[slice, int, np.integer, Variable]],
-) -> Optional[Union[Variable, slice]]:
+    a: slice | int | np.integer | Variable | None,
+) -> Variable | slice | None:
     r"""Convert Python literals to PyTensor constants--when possible--in `Subtensor` arguments.
 
     This will leave `Variable`\s untouched.
@@ -143,7 +142,7 @@ def as_index_constant(
             as_index_constant(a.stop),
             as_index_constant(a.step),
         )
-    elif isinstance(a, (int, np.integer)):
+    elif isinstance(a, int | np.integer):
         return ps.ScalarConstant(ps.int64, a)
     elif not isinstance(a, Variable):
         return as_tensor_variable(a)
@@ -152,8 +151,8 @@ def as_index_constant(
 
 
 def as_index_literal(
-    idx: Optional[Union[Variable, slice]],
-) -> Optional[Union[int, slice]]:
+    idx: Variable | slice | None,
+) -> int | slice | None:
     """Convert a symbolic index element to its Python equivalent.
 
     This is like the inverse of `as_index_constant`
@@ -186,7 +185,7 @@ def get_idx_list(inputs, idx_list):
 
 
 def get_canonical_form_slice(
-    theslice: Union[slice, Variable], length: Variable
+    theslice: slice | Variable, length: Variable
 ) -> tuple[Variable, int]:
     """Convert slices to canonical form.
 
@@ -407,8 +406,8 @@ def is_basic_idx(idx):
     integer can indicate advanced indexing.
 
     """
-    return isinstance(idx, (slice, type(None))) or isinstance(
-        getattr(idx, "type", None), (SliceType, NoneTypeT)
+    return isinstance(idx, slice | type(None)) or isinstance(
+        getattr(idx, "type", None), SliceType | NoneTypeT
     )
 
 
@@ -574,7 +573,7 @@ def index_vars_to_types(entry, slice_ok=True):
 
     """
     if (
-        isinstance(entry, (np.ndarray, Variable))
+        isinstance(entry, np.ndarray | Variable)
         and hasattr(entry, "dtype")
         and entry.dtype == "bool"
     ):
@@ -622,7 +621,7 @@ def index_vars_to_types(entry, slice_ok=True):
             slice_c = None
 
         return slice(slice_a, slice_b, slice_c)
-    elif isinstance(entry, (int, np.integer)):
+    elif isinstance(entry, int | np.integer):
         raise TypeError()
     else:
         raise AdvancedIndexingError("Invalid index type or slice for Subtensor")
@@ -965,7 +964,7 @@ class Subtensor(COp):
             return pos[1]
 
         def init_entry(entry, depth=0):
-            if isinstance(entry, (np.integer, int)):
+            if isinstance(entry, np.integer | int):
                 init_cmds.append("subtensor_spec[%i] = %i;" % (spec_pos(), entry))
                 inc_spec_pos(1)
                 if depth == 0:
@@ -2607,7 +2606,7 @@ class AdvancedSubtensor(Op):
     def infer_shape(self, fgraph, node, ishapes):
         def is_bool_index(idx):
             return (
-                isinstance(idx, (np.bool_, bool))
+                isinstance(idx, np.bool_ | bool)
                 or getattr(idx, "dtype", None) == "bool"
             )
 
@@ -2714,7 +2713,7 @@ class AdvancedIncSubtensor(Op):
 
         new_inputs = []
         for inp in inputs:
-            if isinstance(inp, (list, tuple)):
+            if isinstance(inp, list | tuple):
                 inp = as_tensor_variable(inp)
             new_inputs.append(inp)
         return Apply(
@@ -2820,7 +2819,7 @@ def take(a, indices, axis=None, mode="raise"):
     a = as_tensor_variable(a)
     indices = as_tensor_variable(indices)
 
-    if not isinstance(axis, (int, type(None))):
+    if not isinstance(axis, int | type(None)):
         raise TypeError("`axis` must be an integer or None")
 
     if axis is None:
